From b22207d6ee34f57420e169e05fbe2d1c17ed252a Mon Sep 17 00:00:00 2001
From: Thomas Woerner <twoerner@redhat.com>
Date: Tue, 8 Nov 2022 16:41:56 +0100
Subject: [PATCH] ipaserver_setup_ds: Fix documentation sections and agument
 spec

ansible-test with ansible-2.14 is adding a lot of new tests to ensure
that the documentation section and the agument spec is complete. Needed
changes:

DOCUMENTATION section

- `type: str` needs to be set for string parameters
- `type: list` needs to be set for list parameters
- `elements: str` needs to be given for list of string parameters
- `required` tags need to be fixed according to the `argument_spec`
- `type` tag needs to match `argument_spec`
- `default` tag needs to match `argument_spec`
- `author` needs to be given with the github user also: `Name (@user)`

argument_spec

- `type='str'` needs to be set for string parameters
- `elements='str'` needs to be added to all list of string parameters

A call to ansible_ipa_server.check_imports has been added to check for import
errors.

The `copyright` date is extended with `-2022`.
---
 roles/ipaserver/library/ipaserver_setup_ds.py | 86 ++++++++++++-------
 1 file changed, 56 insertions(+), 30 deletions(-)

diff --git a/roles/ipaserver/library/ipaserver_setup_ds.py b/roles/ipaserver/library/ipaserver_setup_ds.py
index 76fb4b73..4479daaa 100644
--- a/roles/ipaserver/library/ipaserver_setup_ds.py
+++ b/roles/ipaserver/library/ipaserver_setup_ds.py
@@ -5,7 +5,7 @@
 #
 # Based on ipa-client-install code
 #
-# Copyright (C) 2017  Red Hat
+# Copyright (C) 2017-2022  Red Hat
 # see file 'COPYING' for use and warranty information
 #
 # This program is free software; you can redistribute it and/or modify
@@ -39,61 +39,83 @@ description: Configure directory server
 options:
   dm_password:
     description: Directory Manager password
-    required: no
+    type: str
+    required: yes
   password:
     description: Admin user kerberos password
-    required: no
+    type: str
+    required: yes
   domain:
     description: Primary DNS domain of the IPA deployment
-    required: no
+    type: str
+    required: yes
   realm:
     description: Kerberos realm name of the IPA deployment
-    required: no
+    type: str
+    required: yes
   hostname:
     description: Fully qualified name of this host
-    required: yes
+    type: str
+    required: no
   idstart:
     description: The starting value for the IDs range (default random)
-    required: no
+    type: int
+    required: yes
   idmax:
     description: The max value for the IDs range (default idstart+199999)
-    required: no
+    type: int
+    required: yes
   no_hbac_allow:
     description: Don't install allow_all HBAC rule
-    required: yes
+    type: bool
+    default: no
+    required: no
   no_pkinit:
     description: Disable pkinit setup steps
-    required: yes
+    type: bool
+    default: no
+    required: no
   dirsrv_config_file:
     description:
       The path to LDIF file that will be used to modify configuration of
       dse.ldif during installation of the directory server instance
-    required: yes
+    type: str
+    required: no
   dirsrv_cert_files:
     description:
       Files containing the Directory Server SSL certificate and private key
-    required: yes
+    type: list
+    elements: str
+    required: no
   _dirsrv_pkcs12_info:
     description: The installer _dirsrv_pkcs12_info setting
-    required: yes
+    type: list
+    elements: str
+    required: no
   external_cert_files:
     description:
       File containing the IPA CA certificate and the external CA certificate
       chain
-    required: yes
+    type: list
+    elements: str
+    required: no
   subject_base:
     description:
       The certificate subject base (default O=<realm-name>).
       RDNs are in LDAP order (most specific RDN first).
-    required: yes
+    type: str
+    required: no
   ca_subject:
     description: The installer ca_subject setting
-    required: yes
+    type: str
+    required: no
   setup_ca:
     description: Configure a dogtag CA
-    required: yes
+    type: bool
+    default: no
+    required: no
 author:
-    - Thomas Woerner
+    - Thomas Woerner (@t-woerner)
 '''
 
 EXAMPLES = '''
@@ -104,7 +126,7 @@ RETURN = '''
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.ansible_ipa_server import (
     AnsibleModuleLog, setup_logging, options, sysrestore, paths,
     api_Backend_ldap2, redirect_stdout, api, NUM_VERSION, tasks,
     dsinstance, ntpinstance, IPAAPI_USER
 )
@@ -114,24 +136,27 @@ def main():
     ansible_module = AnsibleModule(
         argument_spec=dict(
             # basic
-            dm_password=dict(required=True, no_log=True),
-            password=dict(required=True, no_log=True),
-            domain=dict(required=True),
-            realm=dict(required=True),
-            hostname=dict(required=False),
+            dm_password=dict(required=True, type='str', no_log=True),
+            password=dict(required=True, type='str', no_log=True),
+            domain=dict(required=True, type='str'),
+            realm=dict(required=True, type='str'),
+            hostname=dict(required=False, type='str'),
             # server
             idstart=dict(required=True, type='int'),
             idmax=dict(required=True, type='int'),
             no_hbac_allow=dict(required=False, type='bool', default=False),
             no_pkinit=dict(required=False, type='bool', default=False),
-            dirsrv_config_file=dict(required=False),
+            dirsrv_config_file=dict(required=False, type='str'),
             # ssl certificate
-            dirsrv_cert_files=dict(required=False, type='list', default=[]),
-            _dirsrv_pkcs12_info=dict(required=False, type='list'),
+            dirsrv_cert_files=dict(required=False, type='list', elements='str',
+                                   default=[]),
+            _dirsrv_pkcs12_info=dict(required=False, type='list',
+                                     elements='str'),
             # certificate system
-            external_cert_files=dict(required=False, type='list', default=[]),
-            subject_base=dict(required=False),
-            ca_subject=dict(required=False),
+            external_cert_files=dict(required=False, type='list',
+                                     elements='str', default=[]),
+            subject_base=dict(required=False, type='str'),
+            ca_subject=dict(required=False, type='str'),
 
             # additional
             setup_ca=dict(required=False, type='bool', default=False),
@@ -139,6 +164,7 @@ def main():
     )
 
     ansible_module._ansible_debug = True
+    check_imports(ansible_module)
     setup_logging()
     ansible_log = AnsibleModuleLog(ansible_module)
 
@@ -104,7 +126,7 @@ RETURN = '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.ansible_ipa_server import (
-    AnsibleModuleLog, setup_logging, options, sysrestore, paths,
+    check_imports, AnsibleModuleLog, setup_logging, options, sysrestore, paths,
     api_Backend_ldap2, redirect_stdout, api, NUM_VERSION, tasks,
     dsinstance, ntpinstance, IPAAPI_USER
-- 
GitLab